@@ -1135,6 +1135,18 @@ def test_set_description():
            assert t.desc == ''
            t.set_description('Bye')
            assert t.desc == 'Bye: '
+       assert "World" in our_file.getvalue()
+
+
+   # without refresh
+   with closing(StringIO()) as our_file:
+       with tqdm(desc='Hello', file=our_file) as t:
+           assert t.desc == 'Hello'
+           t.set_description_str('World', False)
+           assert t.desc == 'World'
+           t.set_description(None, False)
+           assert t.desc == ''
+       assert "World" not in our_file.getvalue()
 
 
 @with_setup(pretest, posttest)
@@ -1545,27 +1557,39 @@ def test_postfix():
         assert res in out
         assert res in out2
 
-    # Test postfix set after init and with ordered dict
+    # Test postfix (with ordered dict and no refresh) set after init
     with closing(StringIO()) as our_file:
         with trange(10, file=our_file, desc='pos2 bar', bar_format='{r_bar}',
                     postfix=None) as t3:
-            t3.set_postfix(postfix_order, **postfix)
-            t3.refresh()
+            t3.set_postfix(postfix_order, False, **postfix)
+            t3.refresh()  # explicit external refresh
             out3 = our_file.getvalue()
 
     out3 = out3[1:-1].split(', ')[3:]
     assert out3 == expected_order
 
+    # Test postfix (with ordered dict and refresh) set after init
+    with closing(StringIO()) as our_file:
+        with trange(10, file=our_file, desc='pos2 bar',
+                    bar_format='{r_bar}', postfix=None) as t4:
+            t4.set_postfix(postfix_order, True, **postfix)
+            t4.refresh()  # double refresh
+            out4 = our_file.getvalue()
+
+    assert out4.count('\r') > out3.count('\r')
+    assert out4.count(", ".join(expected_order)) == 2
+
     # Test setting postfix string directly
     with closing(StringIO()) as our_file:
         with trange(10, file=our_file, desc='pos2 bar', bar_format='{r_bar}',
-                    postfix=None) as t4:
-            t4.set_postfix_str("Hello")
-            t4.refresh()
-            out4 = our_file.getvalue()
+                    postfix=None) as t5:
+            t5.set_postfix_str("Hello", False)
+            t5.set_postfix_str("World")
+            out5 = our_file.getvalue()
 
-    out4 = out4[1:-1].split(', ')[3:]
-    assert out4 == ["Hello"]
+    assert "Hello" not in out5
+    out5 = out5[1:-1].split(', ')[3:]
+    assert out5 == ["World"]
 
 
 class DummyTqdmFile(object):
